@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /* gifsicle.c - gifsicle's main loop.
-   Copyright (C) 1997-2007 Eddie Kohler, kohler@icir.org
+   Copyright (C) 1997-2009 Eddie Kohler, ekohler@cs.ucla.edu
    This file is part of gifsicle.
 
    Gifsicle is free software. It is distributed under the GNU Public License,
@@ -196,10 +196,10 @@ static const char *output_option_types[] = {
 #define SCALE_FACTOR_TYPE	(Clp_ValFirstUser + 9)
 
 const Clp_Option options[] = {
-  
+
   { "append", 0, APPEND_OPT, 0, 0 },
   { "app-extension", 'x', APP_EXTENSION_OPT, Clp_ValString, 0 },
-  
+
   { "background", 'B', BACKGROUND_OPT, COLOR_TYPE, Clp_Negate },
   { "batch", 'b', 'b', 0, 0 },
   { "bg", 0, BACKGROUND_OPT, COLOR_TYPE, Clp_Negate },
@@ -216,45 +216,45 @@ const Clp_Option options[] = {
   { "conserve-memory", 0, CONSERVE_MEMORY_OPT, 0, Clp_Negate },
   { "crop", 0, CROP_OPT, RECTANGLE_TYPE, Clp_Negate },
   { "crop-transparency", 0, CROP_TRANSPARENCY_OPT, 0, Clp_Negate },
-  
+
   { "delay", 'd', 'd', Clp_ValInt, Clp_Negate },
   { "delete", 0, DELETE_OPT, 0, 0 },
   { "disposal", 'D', DISPOSAL_OPT, DISPOSAL_TYPE, Clp_Negate },
   { "dither", 'f', DITHER_OPT, 0, Clp_Negate },
   { "done", 0, ALTER_DONE_OPT, 0, 0 },
-  
+
   { "explode", 'e', 'e', 0, 0 },
   { "explode-by-name", 'E', 'E', 0, 0 },
   { "extension", 0, EXTENSION_OPT, Clp_ValString, 0 },
   { "no-extensions", 'x', NO_EXTENSIONS_OPT, 0, 0 },
   { "extension-info", 0, EXTENSION_INFO_OPT, 0, Clp_Negate },
-  
+
   { "flip-horizontal", 0, FLIP_HORIZ_OPT, 0, Clp_Negate },
   { "flip-vertical", 0, FLIP_VERT_OPT, 0, Clp_Negate },
   { "no-flip", 0, NO_FLIP_OPT, 0, 0 },
-  
+
   { "help", 'h', HELP_OPT, 0, 0 },
-  
-  { "info", 'I', INFO_OPT, 0, Clp_Negate },  
+
+  { "info", 'I', INFO_OPT, 0, Clp_Negate },
   { "insert-before", 0, INSERT_OPT, FRAME_SPEC_TYPE, 0 },
   { "interlace", 'i', 'i', 0, Clp_Negate },
-  
+
   { "logical-screen", 'S', LOGICAL_SCREEN_OPT, DIMENSIONS_TYPE, Clp_Negate },
   { "loopcount", 'l', 'l', LOOP_TYPE, Clp_Optional | Clp_Negate },
-  
+
   { "merge", 'm', 'm', 0, 0 },
   { "method", 0, COLORMAP_ALGORITHM_OPT, COLORMAP_ALG_TYPE, 0 },
   { "multifile", 0, MULTIFILE_OPT, 0, Clp_Negate },
-  
+
   { "name", 'n', NAME_OPT, Clp_ValString, 0 },
   { "nextfile", 0, NEXTFILE_OPT, 0, Clp_Negate },
   { "no-names", 'n', NO_NAME_OPT, 0, 0 },
-  
+
   { "optimize", 'O', OPTIMIZE_OPT, Clp_ValInt, Clp_Negate | Clp_Optional },
   { "output", 'o', OUTPUT_OPT, Clp_ValStringNotOption, 0 },
-  
+
   { "position", 'p', POSITION_OPT, POSITION_TYPE, Clp_Negate },
-  
+
   { "replace", 0, REPLACE_OPT, FRAME_SPEC_TYPE, 0 },
   { "resize", 0, RESIZE_OPT, DIMENSIONS_TYPE, Clp_Negate },
   { "resize-width", 0, RESIZE_WIDTH_OPT, Clp_ValUnsigned, Clp_Negate },
@@ -284,23 +284,23 @@ const Clp_Option options[] = {
   { "same-position", 0, SAME_POSITION_OPT, 0, 0 },
   { "same-screen", 0, SAME_LOGICAL_SCREEN_OPT, 0, 0 },
   { "same-transparent", 0, SAME_TRANSPARENT_OPT, 0, 0 },
-  
+
   { "transform-colormap", 0, COLOR_TRANSFORM_OPT, Clp_ValStringNotOption,
     Clp_Negate },
   { "transparent", 't', 't', COLOR_TYPE, Clp_Negate },
-  
+
   { "unoptimize", 'U', UNOPTIMIZE_OPT, 0, Clp_Negate },
   { "use-colormap", 0, USE_COLORMAP_OPT, Clp_ValString, Clp_Negate },
-  
+
   { "verbose", 'V', VERBOSE_OPT, 0, Clp_Negate },
   { 0, 'v', VERBOSE_OPT, 0, Clp_Negate },
   { "version", 0, VERSION_OPT, 0, 0 },
-  
+
   { 0, 'w', NO_WARNINGS_OPT, 0, Clp_Negate },
   { "warnings", 0, WARNINGS_OPT, 0, Clp_Negate },
-  
+
   { "xinfo", 0, EXTENSION_INFO_OPT, 0, Clp_Negate },
-  
+
 };
 
 
@@ -328,7 +328,7 @@ set_frame_change(int kind)
 {
   int i;
   Gt_Frameset *fset;
-  
+
   if (mode == BLANK_MODE)
     set_mode(infoing == 1 ? INFOING : MERGING);
   if (mode < DELETING && frames_done) {
@@ -337,37 +337,37 @@ set_frame_change(int kind)
   }
   assert(!nested_mode);
   nested_mode = mode;
-  
+
   switch (kind) {
-    
+
    case DELETE_OPT:
     mode = DELETING;
     break;
-    
+
    case REPLACE_OPT:
     for (i = frame_spec_1; i < frame_spec_2; i++)
       FRAME(frames, i).use = 0;
     /* We want to use the last frame's delay, but nothing else about it. */
     FRAME(frames, i).use = -1;
     /* FALLTHRU */
-    
+
    case INSERT_OPT:
     /* Define a nested frameset (or use an existing one). */
     fset = FRAME(frames, frame_spec_2).nest;
     if (!fset) fset = new_frameset(8);
     FRAME(frames, frame_spec_2).nest = fset;
-    
+
     /* Later: Merge frames at the end of the nested frameset. */
     mode = INSERTING;
     nested_frames = frames;
     frames = fset;
     break;
-    
+
    case APPEND_OPT:
     /* Just merge frames at the end of this frameset. */
     mode = INSERTING;
     break;
-    
+
   }
 }
 
@@ -388,10 +388,10 @@ show_frame(int imagenumber, int usename)
 {
   Gif_Image *gfi;
   Gt_Frame *frame;
-  
+
   if (!input || !(gfi = Gif_GetImage(input, imagenumber)))
     return;
-  
+
   switch (mode) {
 
    case MERGING:
@@ -404,18 +404,18 @@ show_frame(int imagenumber, int usename)
     if (usename)
       frame->explode_by_name = 1;
     break;
-    
+
    case BATCHING:
     add_frame(frames, first_input_frame + imagenumber, input, gfi);
     break;
-    
+
    case DELETING:
     frame = &FRAME(frames, first_input_frame + imagenumber);
     frame->use = 0;
     break;
-    
+
   }
-  
+
   next_frame = 0;
   frames_done = 1;
 }
@@ -435,13 +435,13 @@ gifread_error(const char *message, int which_image, void *thunk)
   static int different_error_count = 0;
   static int same_error_count = 0;
   const char *filename = (const char *)thunk;
-  
+
   if (gifread_error_count == 0) {
     last_which_image = -1;
     last_message[0] = 0;
     different_error_count = 0;
   }
-  
+
   gifread_error_count++;
   if (last_message[0] && different_error_count <= 10
       && (last_which_image != which_image || message == 0
@@ -456,7 +456,7 @@ gifread_error(const char *message, int which_image, void *thunk)
 
   if (last_message[0] == 0)
     different_error_count++;
-  
+
   same_error_count++;
   if (message)
     strcpy(last_message, message);
@@ -467,7 +467,7 @@ gifread_error(const char *message, int which_image, void *thunk)
     error("Error while reading '%s' frame #%d:", filename, which_image);
     last_which_image = which_image;
   }
-  
+
   if (different_error_count == 11 && message) {
     error("(more errors while reading '%s')", filename);
     different_error_count++;
@@ -487,7 +487,7 @@ open_giffile(const char *name)
 {
   struct StoredFile *sf;
   FILE *f;
-  
+
   if (name == 0 || strcmp(name, "-") == 0) {
 #ifndef OUTPUT_GIF_TO_TERMINAL
     extern int isatty(int);
@@ -505,14 +505,14 @@ open_giffile(const char *name)
 #endif
     return stdin;
   }
-    
+
   if (nextfile)
     for (sf = stored_files; sf; sf = sf->next)
       if (strcmp(name, sf->name) == 0)
 	return sf->f;
-  
+
   f = fopen(name, "rb");
-  
+
   if (f && nextfile) {
     sf = (struct StoredFile *) malloc(sizeof(struct StoredFile) + strlen(name));
     sf->f = f;
@@ -521,7 +521,7 @@ open_giffile(const char *name)
     strcpy(sf->name, name);
   } else if (!f)
     error("%s: %s", name, strerror(errno));
-  
+
   return f;
 }
 
@@ -529,7 +529,7 @@ static void
 close_giffile(FILE *f, int final)
 {
   struct StoredFile **sf_pprev, *sf;
-  
+
   if (!final && nextfile) {
     int c = getc(f);
     if (c == EOF)
@@ -563,7 +563,7 @@ input_stream(const char *name)
   int componentno = 0;
   const char *main_name = 0;
   Gt_Frame old_def_frame;
-  
+
   input = 0;
   input_name = name;
   frames_done = 0;
@@ -594,7 +594,7 @@ input_stream(const char *name)
     sprintf(component_namebuf, "%s~%d", main_name, componentno);
     name = component_namebuf;
   }
-  
+
   /* check for empty file */
   i = getc(f);
   if (i == EOF) {
@@ -606,7 +606,7 @@ input_stream(const char *name)
     return;
   }
   ungetc(i, f);
-  
+
   if (verbosing)
     verbose_open('<', name);
 
@@ -615,7 +615,7 @@ input_stream(const char *name)
   gfs = Gif_FullReadFile(f, gif_read_flags | GIF_READ_COMPRESSED,
 			 gifread_error, (void *)name);
   gifread_error(0, -1, (void *)name); /* print out last error message */
-  
+
   if (!gfs || (Gif_ImageCount(gfs) == 0 && gfs->errors > 0)) {
     if (componentno == 1)
       error("%s: not a GIF image", name);
@@ -634,13 +634,13 @@ input_stream(const char *name)
       fatal_error("%s: --multifile is useful only in merge mode");
     input_done();
   }
-  
+
   input = gfs;
-  
+
   /* Processing when we've got a new input frame */
   if (mode == BLANK_MODE)
     set_mode(MERGING);
-  
+
   if (active_output_data.output_name == 0) {
     /* Don't override explicit output names.
        This code works 'cause output_name is reset to 0 after each output. */
@@ -656,26 +656,26 @@ input_stream(const char *name)
 	active_output_data.output_name = explode_name;
     }
   }
-  
+
   /* This code rather sucks. Here's the problem: Since we consider options
      strictly sequentially, one at a time, we can't tell the difference
      between these:
-     
+
      --name=X g.gif             h.gif   // name on g.gif #0
      --name=X g.gif          #2 h.gif   // name on g.gif #2
               g.gif --name=X #2 h.gif   // name on g.gif #2
               g.gif --name=X    h.gif   // name on h.gif #0 !!!
-      
+
      Here's the solution. Mark when we CHANGE an option. After processing
      an input GIF, mark all the options as 'unchanged' -- but leave the
      VALUES as is. Then when we read the next frame, CLEAR the unchanged
      options. So it's like so: (* means changed, . means not.)
-     
+
      [-.] --name=X [X*] g.gif [X.] #2 [-.] h.gif   == name on g.gif #2
      [-.] g.gif [-.] --name=X [X*] #2 [-.] h.gif  == name on g.gif #2
      [-.] --name=X [X*] g.gif [X.|-.] h.gif  == name on g.gif #0
      [-.] g.gif [-.] --name=X [X*] h.gif  == name on h.gif #0 */
-  
+
   /* Clear old options from the last input stream */
   if (!CHANGED(saved_next_frame, CH_NAME))
     def_frame.name = 0;
@@ -684,7 +684,7 @@ input_stream(const char *name)
   if (!CHANGED(saved_next_frame, CH_EXTENSION))
     def_frame.extensions = 0;
   def_frame.input_filename = input_name;
-  
+
   old_def_frame = def_frame;
   first_input_frame = frames->count;
   if (gfs->nimages > 1)
@@ -692,9 +692,9 @@ input_stream(const char *name)
   for (i = 0; i < gfs->nimages; i++)
     add_frame(frames, -1, gfs, gfs->images[i]);
   def_frame = old_def_frame;
-  
+
   if (unoptimizing)
-    if (!Gif_Unoptimize(gfs)) {
+    if (!Gif_FullUnoptimize(gfs, GIF_UNOPTIMIZE_SIMPLEST_DISPOSAL)) {
       static int context = 0;
       warning("'%s' is too complex to unoptimize", name);
       if (!context) {
@@ -703,7 +703,7 @@ input_stream(const char *name)
       }
       context = 1;
     }
-  
+
   apply_color_transforms(input_transforms, gfs);
   gfs->refcount++;
 
@@ -717,12 +717,12 @@ void
 input_done(void)
 {
   if (!input) return;
-  
+
   if (verbosing) verbose_close('>');
-  
+
   Gif_DeleteStream(input);
   input = 0;
-  
+
   if (mode == DELETING)
     frame_change_done();
   if (mode == BATCHING || mode == EXPLODING)
@@ -747,7 +747,7 @@ set_new_fixed_colormap(const char *name)
       col[i].blue = (i % 6) * 0x33;
     }
     def_output_data.colormap_fixed = cm;
-    
+
   } else if (name && (strcmp(name, "gray") == 0
 		      || strcmp(name, "grey") == 0)) {
     Gif_Colormap *cm = Gif_NewFullColormap(256, 256);
@@ -755,13 +755,13 @@ set_new_fixed_colormap(const char *name)
     for (i = 0; i < 256; i++)
       col[i].red = col[i].green = col[i].blue = i;
     def_output_data.colormap_fixed = cm;
-    
+
   } else if (name && strcmp(name, "bw") == 0) {
     Gif_Colormap *cm = Gif_NewFullColormap(2, 256);
     cm->col[0].red = cm->col[0].green = cm->col[0].blue = 0;
     cm->col[1].red = cm->col[1].green = cm->col[1].blue = 255;
     def_output_data.colormap_fixed = cm;
-    
+
   } else
     def_output_data.colormap_fixed = read_colormap_file(name, 0);
 }
@@ -782,13 +782,13 @@ do_colormap_change(Gif_Stream *gfs)
 {
   if (active_output_data.colormap_fixed)
     do_set_colormap(gfs, active_output_data.colormap_fixed);
-  
+
   if (active_output_data.colormap_size > 0) {
     int nhist;
     Gif_Color *hist;
     Gif_Colormap *(*adapt_func)(Gif_Color *, int, int);
     Gif_Colormap *new_cm;
-    
+
     /* set up the histogram */
     {
       int i, any_locals = 0;
@@ -801,29 +801,29 @@ do_colormap_change(Gif_Stream *gfs)
 	return;
       }
     }
-    
+
     switch (active_output_data.colormap_algorithm) {
-      
+
      case COLORMAP_DIVERSITY:
       adapt_func = &colormap_flat_diversity;
       break;
-      
+
      case COLORMAP_BLEND_DIVERSITY:
       adapt_func = &colormap_blend_diversity;
       break;
-      
+
      case COLORMAP_MEDIAN_CUT:
       adapt_func = &colormap_median_cut;
       break;
-      
+
      default:
       fatal_error("can't happen");
-      
+
     }
-    
+
     new_cm = (*adapt_func)(hist, nhist, active_output_data.colormap_size);
     do_set_colormap(gfs, new_cm);
-    
+
     Gif_DeleteArray(hist);
     Gif_DeleteColormap(new_cm);
   }
@@ -838,7 +838,7 @@ static void
 write_stream(const char *output_name, Gif_Stream *gfs)
 {
   FILE *f;
-  
+
   if (output_name)
     f = fopen(output_name, "wb");
   else {
@@ -859,7 +859,7 @@ write_stream(const char *output_name, Gif_Stream *gfs)
     f = stdout;
     output_name = "<stdout>";
   }
-  
+
   if (f) {
     Gif_FullWriteFile(gfs, gif_write_flags, f);
     fclose(f);
@@ -892,7 +892,7 @@ merge_and_write_frames(const char *outfile, int f1, int f2)
 
   out = merge_frame_interval(frames, f1, f2, &active_output_data,
 			     compress_immediately, &huge_stream);
-  
+
   if (out) {
     if (active_output_data.scaling == 1)
       resize_stream(out, active_output_data.resize_width,
@@ -909,7 +909,7 @@ merge_and_write_frames(const char *outfile, int f1, int f2)
     write_stream(outfile, out);
     Gif_DeleteStream(out);
   }
-  
+
   if (verbosing) verbose_close(']');
 }
 
@@ -920,7 +920,7 @@ output_information(const char *outfile)
   int i, j;
   Gt_Frame *fr;
   Gif_Stream *gfs;
-  
+
   if (infoing == 2)
     f = stderr;
   else if (outfile == 0)
@@ -932,7 +932,7 @@ output_information(const char *outfile)
       return;
     }
   }
-  
+
   for (i = 0; i < frames->count; i++)
     FRAME(frames, i).stream->userflags = 97;
 
@@ -949,7 +949,7 @@ output_information(const char *outfile)
 	  image_info(f, gfs, fr->image, fr->colormap_info);
 	}
     }
-  
+
   if (f != stderr && f != stdout)
     fclose(f);
 }
@@ -964,20 +964,20 @@ output_frames(void)
   int i;
   const char *outfile = active_output_data.output_name;
   active_output_data.output_name = 0;
-  
+
   /* Output information only now. */
   if (infoing)
     output_information(outfile);
-  
+
   if (infoing != 1 && frames->count > 0)
     switch (mode) {
-      
+
      case MERGING:
      case BATCHING:
      case INFOING:
       merge_and_write_frames(outfile, 0, -1);
       break;
-      
+
      case EXPLODING: {
        /* Use the current output name for consistency, even though that means
 	  we can't explode different frames to different names. Not a big deal
@@ -988,35 +988,35 @@ output_frames(void)
 	 if (fr->stream->nimages > max_nimages)
 	   max_nimages = fr->stream->nimages;
        }
-       
+
        if (!outfile) /* Watch out! */
 	 outfile = "-";
-       
+
        for (i = 0; i < frames->count; i++) {
 	 Gt_Frame *fr = &FRAME(frames, i);
 	 int imagenumber = Gif_ImageNumber(fr->stream, fr->image);
 	 char *explodename;
-	 
+
 	 const char *imagename = 0;
 	 if (fr->explode_by_name)
 	   imagename = fr->name ? fr->name : fr->image->identifier;
-	 
+
 	 explodename = explode_filename(outfile, imagenumber, imagename,
 					max_nimages);
 	 merge_and_write_frames(explodename, i, i);
        }
        break;
      }
-     
+
      case INSERTING:
       /* do nothing */
       break;
-      
+
     }
-  
+
   active_next_output = 0;
   clear_frameset(frames, 0);
-  
+
   /* cropping: clear the 'crop->ready' information, which depended on the last
      input image. */
   if (def_frame.crop)
@@ -1068,12 +1068,12 @@ handle_extension(Clp_Parser *clp, int is_app)
       fatal_error("bad extension type: must be a number between 0 and 255");
     gfex = Gif_NewExtension(l, 0);
   }
-  
+
   gfex->data = (uint8_t *)extension_body;
   gfex->length = strlen(extension_body);
   gfex->next = def_frame.extensions;
   def_frame.extensions = gfex;
-  
+
   return 1;
 }
 
@@ -1089,51 +1089,51 @@ initialize_def_frame(void)
   def_frame.stream = 0;
   def_frame.image = 0;
   def_frame.use = 1;
-  
+
   def_frame.name = 0;
   def_frame.no_name = 0;
   def_frame.comment = 0;
   def_frame.no_comments = 0;
-  
+
   def_frame.interlacing = -1;
   def_frame.transparent.haspixel = 0;
   def_frame.left = -1;
   def_frame.top = -1;
   def_frame.position_is_offset = 0;
-  
+
   def_frame.crop = 0;
-  
+
   def_frame.delay = -1;
   def_frame.disposal = -1;
-  
+
   def_frame.nest = 0;
   def_frame.explode_by_name = 0;
-  
+
   def_frame.no_extensions = 0;
   def_frame.extensions = 0;
-  
+
   def_frame.flip_horizontal = 0;
   def_frame.flip_vertical = 0;
   def_frame.total_crop = 0;
-  
+
   /* output defaults */
   def_output_data.output_name = 0;
-  
+
   def_output_data.screen_width = -1;
   def_output_data.screen_height = -1;
   def_output_data.background.haspixel = 0;
   def_output_data.loopcount = -2;
-  
+
   def_output_data.colormap_size = 0;
   def_output_data.colormap_fixed = 0;
   def_output_data.colormap_algorithm = COLORMAP_DIVERSITY;
   def_output_data.colormap_dither = 0;
-  
+
   def_output_data.optimizing = 0;
   def_output_data.scaling = 0;
 
   def_output_data.conserve_memory = 0;
-  
+
   active_output_data = def_output_data;
 }
 
@@ -1147,9 +1147,9 @@ combine_output_options(void)
     MARK_CH(output, value);				\
     active_output_data.field = def_output_data.field;	\
   }
-  
+
   COMBINE_ONE_OUTPUT_OPTION(CH_OUTPUT, output_name);
-  
+
   if (CHANGED(recent, CH_LOGICAL_SCREEN)) {
     MARK_CH(output, CH_LOGICAL_SCREEN);
     active_output_data.screen_width = def_output_data.screen_width;
@@ -1157,7 +1157,7 @@ combine_output_options(void)
   }
   COMBINE_ONE_OUTPUT_OPTION(CH_BACKGROUND, background);
   COMBINE_ONE_OUTPUT_OPTION(CH_LOOPCOUNT, loopcount);
-  
+
   COMBINE_ONE_OUTPUT_OPTION(CH_OPTIMIZE, optimizing);
   COMBINE_ONE_OUTPUT_OPTION(CH_COLORMAP, colormap_size);
   COMBINE_ONE_OUTPUT_OPTION(CH_COLORMAP_METHOD, colormap_algorithm);
@@ -1169,7 +1169,7 @@ combine_output_options(void)
     active_output_data.colormap_fixed = def_output_data.colormap_fixed;
   }
   COMBINE_ONE_OUTPUT_OPTION(CH_DITHER, colormap_dither);
-  
+
   if (CHANGED(recent, CH_RESIZE)) {
     MARK_CH(output, CH_RESIZE);
     active_output_data.scaling = def_output_data.scaling;
@@ -1180,10 +1180,10 @@ combine_output_options(void)
   }
 
   COMBINE_ONE_OUTPUT_OPTION(CH_MEMORY, conserve_memory);
-  
+
   def_output_data.colormap_fixed = 0;
   def_output_data.output_name = 0;
-  
+
   active_next_output |= next_output;
   next_output = 0;
 }
@@ -1239,7 +1239,7 @@ main(int argc, char *argv[])
 {
   Clp_Parser *clp =
     Clp_NewParser(argc, (const char * const *)argv, sizeof(options) / sizeof(options[0]), options);
-  
+
   Clp_AddStringListType
     (clp, LOOP_TYPE, Clp_AllowNumbers,
      "infinite", 0, "forever", 0,
@@ -1267,16 +1267,16 @@ main(int argc, char *argv[])
   Clp_AddType(clp, TWO_COLORS_TYPE, Clp_DisallowOptions, parse_two_colors, 0);
   Clp_SetOptionChar(clp, '+', Clp_ShortNegated);
   Clp_SetErrorHandler(clp, clp_error_handler);
-  
+
   program_name = Clp_ProgramName(clp);
-  
+
   frames = new_frameset(16);
   initialize_def_frame();
-  
+
 #ifdef DMALLOC
   dmalloc_verbose("fudge");
 #endif
-  
+
   /* Yep, I'm an idiot.
      GIF dimensions are unsigned 16-bit integers. I assume that these
      numbers will fit in an 'int'. This assertion tests that assumption.
@@ -1287,33 +1287,33 @@ main(int argc, char *argv[])
     int i = m;
     assert(i > 0 && "configuration/lameness failure! bug the author!");
   }
-  
+
   while (1) {
     int opt = Clp_Next(clp);
     switch (opt) {
-      
+
       /* MODE OPTIONS */
-      
+
      case 'b':
       set_mode(BATCHING);
       break;
-      
+
      case 'm':
       set_mode(MERGING);
       break;
-      
+
      case 'e':
       set_mode(EXPLODING);
       def_frame.explode_by_name = 0;
       break;
-      
+
      case 'E':
       set_mode(EXPLODING);
       def_frame.explode_by_name = 1;
       break;
-      
+
       /* INFORMATION OPTIONS */
-      
+
      case INFO_OPT:
       if (clp->negated)
 	infoing = 0;
@@ -1322,7 +1322,7 @@ main(int argc, char *argv[])
            suppress) */
 	infoing = (infoing == 1 ? 2 : 1);
       break;
-      
+
      case COLOR_INFO_OPT:
       if (clp->negated)
 	def_frame.colormap_info = 0;
@@ -1332,7 +1332,7 @@ main(int argc, char *argv[])
 	  infoing = 1;
       }
       break;
-      
+
      case EXTENSION_INFO_OPT:
       if (clp->negated)
 	def_frame.extensions_info = 0;
@@ -1342,13 +1342,13 @@ main(int argc, char *argv[])
 	  infoing = 1;
       }
       break;
-      
+
      case VERBOSE_OPT:
       verbosing = clp->negated ? 0 : 1;
       break;
-      
+
       /* FRAME CHANGE OPTIONS */
-      
+
      case DELETE_OPT:
      case REPLACE_OPT:
      case INSERT_OPT:
@@ -1356,69 +1356,69 @@ main(int argc, char *argv[])
       frame_change_done();
       set_frame_change(opt);
       break;
-      
+
      case ALTER_DONE_OPT:
       frame_change_done();
       break;
-      
+
       /* IMAGE OPTIONS */
-      
+
      case NAME_OPT:
       if (clp->negated) goto no_names;
       MARK_CH(frame, CH_NAME);
       def_frame.name = clp->vstr;
       break;
-      
+
      no_names:
      case NO_NAME_OPT:
       MARK_CH(frame, CH_NAME);
       def_frame.no_name = 1;
       def_frame.name = 0;
       break;
-      
+
      case SAME_NAME_OPT:
       def_frame.no_name = 0;
       def_frame.name = 0;
       break;
-      
+
      case COMMENT_OPT:
       if (clp->negated) goto no_comments;
       MARK_CH(frame, CH_COMMENT);
       if (!def_frame.comment) def_frame.comment = Gif_NewComment();
       Gif_AddComment(def_frame.comment, clp->vstr, -1);
       break;
-      
+
      no_comments:
      case NO_COMMENTS_OPT:
       Gif_DeleteComment(def_frame.comment);
       def_frame.comment = 0;
       def_frame.no_comments = 1;
       break;
-      
+
      case SAME_COMMENTS_OPT:
       def_frame.no_comments = 0;
       break;
-      
+
      case 'i':
       MARK_CH(frame, CH_INTERLACE);
       def_frame.interlacing = clp->negated ? 0 : 1;
       break;
-      
+
      case SAME_INTERLACE_OPT:
       def_frame.interlacing = -1;
       break;
-      
+
      case POSITION_OPT:
       MARK_CH(frame, CH_POSITION);
       def_frame.left = clp->negated ? 0 : position_x;
       def_frame.top = clp->negated ? 0 : position_y;
       break;
-      
+
      case SAME_POSITION_OPT:
       def_frame.left = -1;
       def_frame.top = -1;
       break;
-      
+
      case 't':
       MARK_CH(frame, CH_TRANSPARENT);
       if (clp->negated)
@@ -1428,11 +1428,11 @@ main(int argc, char *argv[])
 	def_frame.transparent.haspixel = parsed_color.haspixel ? 2 : 1;
       }
       break;
-      
+
      case SAME_TRANSPARENT_OPT:
       def_frame.transparent.haspixel = 0;
       break;
-      
+
      case BACKGROUND_OPT:
       MARK_CH(output, CH_BACKGROUND);
       if (clp->negated) {
@@ -1443,12 +1443,12 @@ main(int argc, char *argv[])
 	def_output_data.background.haspixel = parsed_color.haspixel ? 2 : 1;
       }
       break;
-      
+
      case SAME_BACKGROUND_OPT:
       MARK_CH(output, CH_BACKGROUND);
       def_output_data.background.haspixel = 0;
       break;
-      
+
      case LOGICAL_SCREEN_OPT:
       MARK_CH(output, CH_LOGICAL_SCREEN);
       if (clp->negated)
@@ -1458,12 +1458,12 @@ main(int argc, char *argv[])
 	def_output_data.screen_height = dimensions_y;
       }
       break;
-      
+
      case SAME_LOGICAL_SCREEN_OPT:
       MARK_CH(output, CH_LOGICAL_SCREEN);
       def_output_data.screen_width = def_output_data.screen_height = -1;
       break;
-      
+
      case CROP_OPT:
       if (clp->negated) goto no_crop;
       MARK_CH(frame, CH_CROP);
@@ -1477,7 +1477,7 @@ main(int argc, char *argv[])
 	def_frame.crop = crop;
       }
       break;
-      
+
      no_crop:
      case SAME_CROP_OPT:
       def_frame.crop = 0;
@@ -1495,73 +1495,73 @@ main(int argc, char *argv[])
 	def_frame.crop->transparent_edges = 0;
       }
       break;
-      
+
       /* extensions options */
-      
+
      case NO_EXTENSIONS_OPT:
       def_frame.no_extensions = 1;
       break;
-      
+
      case SAME_EXTENSIONS_OPT:
       def_frame.no_extensions = 0;
       break;
-      
+
      case EXTENSION_OPT:
       if (!handle_extension(clp, 0))
 	goto bad_option;
       break;
-      
+
      case APP_EXTENSION_OPT:
       if (!handle_extension(clp, 1))
 	goto bad_option;
       break;
-      
+
       /* IMAGE DATA OPTIONS */
-      
+
      case FLIP_HORIZ_OPT:
       MARK_CH(frame, CH_FLIP);
       def_frame.flip_horizontal = !clp->negated;
       break;
-      
+
      case FLIP_VERT_OPT:
       MARK_CH(frame, CH_FLIP);
       def_frame.flip_vertical = !clp->negated;
       break;
-       
+
      case NO_FLIP_OPT:
       def_frame.flip_horizontal = def_frame.flip_vertical = 0;
       break;
-      
+
      case NO_ROTATE_OPT:
       def_frame.rotation = 0;
       break;
-       
+
      case ROTATE_90_OPT:
       MARK_CH(frame, CH_ROTATE);
       def_frame.rotation = 1;
       break;
-       
+
      case ROTATE_180_OPT:
       MARK_CH(frame, CH_ROTATE);
       def_frame.rotation = 2;
       break;
-      
+
      case ROTATE_270_OPT:
       MARK_CH(frame, CH_ROTATE);
       def_frame.rotation = 3;
       break;
-       
+
       /* ANIMATION OPTIONS */
-      
+
      case 'd':
       MARK_CH(frame, CH_DELAY);
       def_frame.delay = clp->negated ? 0 : clp->val.i;
       break;
-      
+
      case SAME_DELAY_OPT:
       def_frame.delay = -1;
       break;
-      
+
      case DISPOSAL_OPT:
       MARK_CH(frame, CH_DISPOSAL);
       if (clp->negated)
@@ -1571,11 +1571,11 @@ main(int argc, char *argv[])
       else
 	def_frame.disposal = clp->val.i;
       break;
-      
+
      case SAME_DISPOSAL_OPT:
       def_frame.disposal = -1;
       break;
-      
+
      case 'l':
       MARK_CH(output, CH_LOOPCOUNT);
       if (clp->negated)
@@ -1583,12 +1583,12 @@ main(int argc, char *argv[])
       else
 	def_output_data.loopcount = (clp->have_val ? clp->val.i : 0);
       break;
-      
+
      case SAME_LOOPCOUNT_OPT:
       MARK_CH(output, CH_LOOPCOUNT);
       def_output_data.loopcount = -2;
       break;
-      
+
      case OPTIMIZE_OPT:
       MARK_CH(output, CH_OPTIMIZE);
       if (clp->negated)
@@ -1596,12 +1596,12 @@ main(int argc, char *argv[])
       else
 	def_output_data.optimizing = (clp->have_val ? clp->val.i : 1);
       break;
-      
+
      case UNOPTIMIZE_OPT:
       UNCHECKED_MARK_CH(input, CH_UNOPTIMIZE);
       unoptimizing = clp->negated ? 0 : 1;
       break;
-      
+
       /* WHOLE-GIF OPTIONS */
 
      case CAREFUL_OPT: {
@@ -1611,7 +1611,7 @@ main(int argc, char *argv[])
 	 gif_write_flags = GIF_WRITE_CAREFUL_MIN_CODE_SIZE;
        break;
      }
-     
+
      case CHANGE_COLOR_OPT: {
        next_input |= CH_CHANGE_COLOR;
        if (clp->negated)
@@ -1624,7 +1624,7 @@ main(int argc, char *argv[])
 	   (input_transforms, parsed_color, parsed_color2);
        break;
      }
-     
+
      case COLOR_TRANSFORM_OPT:
       next_output |= CH_COLOR_TRANSFORM;
       if (clp->negated)
@@ -1634,7 +1634,7 @@ main(int argc, char *argv[])
 	output_transforms = append_color_transform
 	  (output_transforms, &pipe_color_transformer, (void *)clp->vstr);
       break;
-      
+
      case COLORMAP_OPT:
       MARK_CH(output, CH_COLORMAP);
       if (clp->negated)
@@ -1648,7 +1648,7 @@ main(int argc, char *argv[])
 	}
       }
       break;
-      
+
      case USE_COLORMAP_OPT:
       MARK_CH(output, CH_USE_COLORMAP);
       Gif_DeleteColormap(def_output_data.colormap_fixed);
@@ -1657,17 +1657,17 @@ main(int argc, char *argv[])
       else
 	set_new_fixed_colormap(clp->vstr);
       break;
-      
+
      case COLORMAP_ALGORITHM_OPT:
       MARK_CH(output, CH_COLORMAP_METHOD);
       def_output_data.colormap_algorithm = clp->val.i;
       break;
-      
+
      case DITHER_OPT:
       MARK_CH(output, CH_DITHER);
       def_output_data.colormap_dither = !clp->negated;
       break;
-      
+
      case RESIZE_OPT:
       MARK_CH(output, CH_RESIZE);
       if (clp->negated)
@@ -1681,7 +1681,7 @@ main(int argc, char *argv[])
 	def_output_data.resize_height = dimensions_y;
       }
       break;
-      
+
      case RESIZE_WIDTH_OPT:
       MARK_CH(output, CH_RESIZE);
       if (clp->negated)
@@ -1695,7 +1695,7 @@ main(int argc, char *argv[])
 	def_output_data.resize_height = 0;
       }
       break;
-      
+
      case RESIZE_HEIGHT_OPT:
       MARK_CH(output, CH_RESIZE);
       if (clp->negated)
@@ -1709,7 +1709,7 @@ main(int argc, char *argv[])
 	def_output_data.resize_height = clp->val.u;
       }
       break;
-      
+
      case SCALE_OPT:
       MARK_CH(output, CH_RESIZE);
       if (clp->negated)
@@ -1723,13 +1723,13 @@ main(int argc, char *argv[])
 	def_output_data.scale_y = parsed_scale_factor_y;
       }
       break;
-      
+
       /* RANDOM OPTIONS */
-      
+
      case NO_WARNINGS_OPT:
       no_warnings = !clp->negated;
       break;
-      
+
      case WARNINGS_OPT:
       no_warnings = clp->negated;
       break;
@@ -1763,18 +1763,18 @@ main(int argc, char *argv[])
 #else
       printf("LCDF Gifsicle %s\n", VERSION);
 #endif
-      printf("Copyright (C) 1997-2008 Eddie Kohler\n\
+      printf("Copyright (C) 1997-2009 Eddie Kohler\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
       exit(EXIT_OK);
       break;
-      
+
      case HELP_OPT:
       usage();
       exit(EXIT_OK);
       break;
-      
+
      case OUTPUT_OPT:
       MARK_CH(output, CH_OUTPUT);
       if (strcmp(clp->vstr, "-") == 0)
@@ -1782,43 +1782,43 @@ particular purpose.\n");
       else
 	def_output_data.output_name = clp->vstr;
       break;
-      
+
       /* NONOPTIONS */
-      
+
      case Clp_NotOption:
       if (clp->vstr[0] != '#' || !frame_argument(clp, clp->vstr)) {
 	input_done();
 	input_stream(clp->vstr);
       }
       break;
-      
+
      case Clp_Done:
       goto done;
-      
+
      bad_option:
      case Clp_BadOption:
       short_usage();
       exit(EXIT_USER_ERR);
       break;
-      
+
      default:
       break;
-      
+
     }
   }
-  
+
  done:
-  
+
   if (next_output)
     combine_output_options();
   if (!files_given)
     input_stream(0);
-  
+
   frame_change_done();
   input_done();
   if (mode == MERGING || mode == INFOING)
     output_frames();
-  
+
   verbose_endline();
   print_useless_options("frame", next_frame, frame_option_types);
   print_useless_options("input", next_input, input_option_types);
