@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /* gifview.c - gifview's main loop.
-   Copyright (C) 1997-2002 Eddie Kohler, eddietwo@lcs.mit.edu
+   Copyright (C) 1997-2008 Eddie Kohler, ekohler@gmail.com
    This file is part of gifview, in the gifsicle package.
 
    Gifview is free software. It is distributed under the GNU Public License,
@@ -31,6 +31,13 @@
 #include <errno.h>
 #include <assert.h>
 
+/* Need _setmode under MS-DOS, to set stdin/stdout to binary mode */
+/* Need _fsetmode under OS/2 for the same reason */
+#if defined(_MSDOS) || defined(_WIN32) || defined(__EMX__) || defined(__DJGPP__)
+# include <fcntl.h>
+# include <io.h>
+#endif
+
 #ifdef __cplusplus
 #define EXTERN extern "C"
 #else
@@ -93,7 +100,7 @@ struct timeval genesis_time;
  **/
 
 typedef struct Gt_Viewer {
-  
+
   Display *display;
   int screen_number;
   Visual *visual;
@@ -102,32 +109,33 @@ typedef struct Gt_Viewer {
   Gif_XContext *gfx;
   Cursor arrow_cursor;
   Cursor wait_cursor;
-  
+
   Window parent;
   int top_level;
-  
+
   Window window;
   int use_window;
   int width;
   int height;
   int resizable;
   int being_deleted;
-  
+
   Gif_Stream *gfs;
   const char *name;
+  const char *title;
 
   Gif_Image **im;
   int nim;
-  
+
   Pixmap pixmap;
   int im_pos;
   int was_unoptimized;
   int free_pixmaps;
-  
-  Pixmap *unoptimized_pixmaps;
-  
+
+  Gif_XFrame *unoptimized_frames;
+
   struct Gt_Viewer *next;
-  
+
   int can_animate;
   int animating;
   int unoptimizing;
@@ -136,7 +144,7 @@ typedef struct Gt_Viewer {
   struct Gt_Viewer *anim_next;
   struct timeval timer;
   int anim_loop;
-  
+
 } Gt_Viewer;
 
 const char *program_name = "gifview";
@@ -147,6 +155,7 @@ static const char *cur_geometry_spec = 0;
 static Cursor cur_arrow_cursor = 0;
 static Cursor cur_wait_cursor = 0;
 static const char *cur_resource_name;
+static const char *cur_window_title = 0;
 static Window cur_use_window = None;
 static int cur_use_window_new = 0;
 static const char *cur_background_color = "black";
@@ -173,23 +182,25 @@ static struct timeval preparation_time;
 #define INTERACTIVE_OPT		309
 #define BACKGROUND_OPT		310
 #define NEW_WINDOW_OPT		311
+#define TITLE_OPT		312
 
-#define WINDOW_TYPE		(Clp_FirstUserType)
+#define WINDOW_TYPE		(Clp_ValFirstUser)
 
-Clp_Option options[] = {
+const Clp_Option options[] = {
   { "animate", 'a', ANIMATE_OPT, 0, Clp_Negate },
-  { "background", 'b', BACKGROUND_OPT, Clp_ArgString, 0 },
-  { "bg", 't', BACKGROUND_OPT, Clp_ArgString, 0 },
-  { "display", 'd', DISPLAY_OPT, Clp_ArgStringNotOption, 0 },
-  { "geometry", 'g', GEOMETRY_OPT, Clp_ArgString, 0 },
+  { "background", 'b', BACKGROUND_OPT, Clp_ValString, 0 },
+  { "bg", 't', BACKGROUND_OPT, Clp_ValString, 0 },
+  { "display", 'd', DISPLAY_OPT, Clp_ValStringNotOption, 0 },
+  { "geometry", 'g', GEOMETRY_OPT, Clp_ValString, 0 },
   { "install-colormap", 'i', INSTALL_COLORMAP_OPT, 0, Clp_Negate },
   { "interactive", 'e', INTERACTIVE_OPT, 0, Clp_Negate },
   { "help", 0, HELP_OPT, 0, 0 },
-  { "name", 0, NAME_OPT, Clp_ArgString, 0 },
+  { "name", 0, NAME_OPT, Clp_ValString, 0 },
+  { "title", 'T', TITLE_OPT, Clp_ValString, 0 },
   { "unoptimize", 'U', UNOPTIMIZE_OPT, 0, Clp_Negate },
   { "version", 0, VERSION_OPT, 0, 0 },
   { "window", 'w', WINDOW_OPT, WINDOW_TYPE, 0 },
-  { "new-window", 0, NEW_WINDOW_OPT, WINDOW_TYPE, 0 },
+  { "new-window", 0, NEW_WINDOW_OPT, WINDOW_TYPE, 0 }
 };
 
 
@@ -251,6 +262,7 @@ Options are:\n\
   -d, --display DISPLAY         Set display to DISPLAY.\n\
       --name NAME               Set application resource name to NAME.\n\
   -g, --geometry GEOMETRY       Set window geometry.\n\
+  -T, --title TITLE             Set window title.\n\
   -w, --window WINDOW           Show GIF in existing WINDOW.\n\
       --new-window WINDOW       Show GIF in new child of existing WINDOW.\n\
   -i, --install-colormap        Use a private colormap.\n\
@@ -262,7 +274,7 @@ Options are:\n\
 Frame selections:               #num, #num1-num2, #num1-, #name\n\
 \n\
 Keystrokes:\n\
-  [Space] Go to next frame.             [B] Go to previous frame.\n\
+  [N]/[Space] Go to next frame.         [P]/[B] Go to previous frame.\n\
   [R]/[<] Go to first frame.            [>] Go to last frame.\n\
   [ESC] Stop animation.                 [S]/[A] Toggle animation.\n\
   [U] Toggle unoptimization.            [Backspace]/[W] Delete window.\n\
@@ -270,7 +282,7 @@ Keystrokes:\n\
 \n\
 Left mouse button goes to next frame, right mouse button deletes window.\n\
 \n\
-Report bugs to <eddietwo@lcs.mit.edu>.\n", program_name);
+Report bugs to <ekohler@gmail.com>.\n", program_name);
 }
 
 
@@ -290,12 +302,12 @@ choose_visual(Gt_Viewer *viewer)
   Display *display = viewer->display;
   int screen_number = viewer->screen_number;
   VisualID default_visualid = DefaultVisual(display, screen_number)->visualid;
-  
+
   XVisualInfo visi_template;
   int nv, i;
   XVisualInfo *v, *best_v = 0;
   Gt_Viewer *trav;
-  
+
   /* Look for an existing Gt_Viewer with the same display and screen number */
   if (!install_colormap)
     for (trav = viewers; trav; trav = trav->next)
@@ -308,24 +320,24 @@ choose_visual(Gt_Viewer *viewer)
 	viewer->gfx->refcount++;
 	return;
       }
-  
+
   /* Find the default visual's XVisualInfo & put it in best_v */
   visi_template.screen = screen_number;
   v = XGetVisualInfo(display, VisualScreenMask, &visi_template, &nv);
   for (i = 0; i < nv && !best_v; i++)
     if (v[i].visualid == default_visualid)
       best_v = &v[i];
-  
+
   if (!best_v) {
-    
+
     /* This should never happen. If we can't find the default visual's
        XVisualInfo, we just use the default visual */
     viewer->visual = DefaultVisual(display, screen_number);
     viewer->depth = DefaultDepth(display, screen_number);
     viewer->colormap = DefaultColormap(display, screen_number);
-    
+
   } else {
-    
+
     /* Which visual to choose? This isn't exactly a simple decision, since
        we want to avoid colormap flashing while choosing a nice visual. So
        here's the algorithm: Prefer the default visual, or take a TrueColor
@@ -333,7 +345,7 @@ choose_visual(Gt_Viewer *viewer)
     for (i = 0; i < nv; i++)
       if (v[i].depth > best_v->depth && v[i].VISUAL_CLASS == TrueColor)
 	best_v = &v[i];
-    
+
     viewer->visual = best_v->visual;
     viewer->depth = best_v->depth;
     if (best_v->visualid != default_visualid
@@ -343,13 +355,13 @@ choose_visual(Gt_Viewer *viewer)
 			viewer->visual, AllocNone);
     else
       viewer->colormap = DefaultColormap(display, screen_number);
-    
+
   }
-  
+
   viewer->gfx = Gif_NewXContextFromVisual
     (display, screen_number, viewer->visual, viewer->depth, viewer->colormap);
   viewer->gfx->refcount++;
-  
+
   if (v) XFree(v);
 }
 
@@ -359,11 +371,11 @@ new_viewer(Display *display, Gif_Stream *gfs, const char *name)
 {
   Gt_Viewer *viewer;
   int i;
-  
+
   /* Make the Gt_Viewer structure */
   viewer = Gif_New(Gt_Viewer);
   viewer->display = display;
-  
+
   if (cur_use_window) {
     XWindowAttributes attr;
 
@@ -371,19 +383,19 @@ new_viewer(Display *display, Gif_Stream *gfs, const char *name)
       viewer->screen_number = DefaultScreen(display);
       cur_use_window = RootWindow(display, viewer->screen_number);
     }
-    
+
     XGetWindowAttributes(display, cur_use_window, &attr);
-    
+
     viewer->screen_number = -1;
     for (i = 0; i < ScreenCount(display); i++)
       if (ScreenOfDisplay(display, i) == attr.screen)
 	viewer->screen_number = i;
     assert(viewer->screen_number >= 0);
-    
+
     viewer->visual = attr.visual;
     viewer->depth = attr.depth;
     viewer->colormap = attr.colormap;
-    
+
     viewer->gfx = Gif_NewXContextFromVisual
       (display, viewer->screen_number, viewer->visual, viewer->depth,
        viewer->colormap);
@@ -402,7 +414,7 @@ new_viewer(Display *display, Gif_Stream *gfs, const char *name)
     viewer->parent = cur_use_window;
     viewer->top_level = 0;
     viewer->resizable = 0;
-    
+
   } else {
     viewer->screen_number = DefaultScreen(display);
     choose_visual(viewer);
@@ -412,7 +424,7 @@ new_viewer(Display *display, Gif_Stream *gfs, const char *name)
     viewer->top_level = 1;
     viewer->resizable = 1;
   }
-  
+
   /* assign background color */
   if (cur_background_color) {
     XColor color;
@@ -443,11 +455,12 @@ new_viewer(Display *display, Gif_Stream *gfs, const char *name)
   }
   viewer->arrow_cursor = cur_arrow_cursor;
   viewer->wait_cursor = cur_wait_cursor;
-  
+
   viewer->being_deleted = 0;
   viewer->gfs = gfs;
   gfs->refcount++;
   viewer->name = name;
+  viewer->title = cur_window_title;
   viewer->nim = Gif_ImageCount(gfs);
   viewer->im = Gif_NewArray(Gif_Image *, viewer->nim);
   for (i = 0; i < viewer->nim; i++)
@@ -456,9 +469,7 @@ new_viewer(Display *display, Gif_Stream *gfs, const char *name)
   viewer->im_pos = -1;
   viewer->was_unoptimized = 0;
   viewer->free_pixmaps = 1;
-  viewer->unoptimized_pixmaps = Gif_NewArray(Pixmap, viewer->nim);
-  for (i = 0; i < viewer->nim; i++)
-    viewer->unoptimized_pixmaps[i] = None;
+  viewer->unoptimized_frames = Gif_NewXFrames(gfs);
   viewer->next = viewers;
   viewers = viewer;
   viewer->animating = 0;
@@ -468,7 +479,7 @@ new_viewer(Display *display, Gif_Stream *gfs, const char *name)
   viewer->anim_next = 0;
   viewer->anim_loop = 0;
   viewer->timer.tv_sec = viewer->timer.tv_usec = 0;
-  
+
   return viewer;
 }
 
@@ -480,17 +491,14 @@ delete_viewer(Gt_Viewer *viewer)
   int i;
   if (viewer->pixmap && !viewer->was_unoptimized)
     XFreePixmap(viewer->display, viewer->pixmap);
-  for (i = 0; i < viewer->nim; i++)
-    if (viewer->unoptimized_pixmaps[i])
-      XFreePixmap(viewer->display, viewer->unoptimized_pixmaps[i]);
-  
+
   for (trav = viewers; trav != viewer; prev = trav, trav = trav->next)
     ;
   if (prev) prev->next = viewer->next;
   else viewers = viewer->next;
-  
+
+  Gif_DeleteXFrames(viewer->gfx, viewer->gfs, viewer->unoptimized_frames);
   Gif_DeleteStream(viewer->gfs);
-  Gif_DeleteArray(viewer->unoptimized_pixmaps);
   Gif_DeleteArray(viewer->im);
   Gif_DeleteXContext(viewer->gfx);
   Gif_Delete(viewer);
@@ -510,9 +518,23 @@ get_input_stream(const char *name)
 {
   FILE *f;
   Gif_Stream *gfs = 0;
-  
+
   if (name == 0 || strcmp(name, "-") == 0) {
+#ifndef OUTPUT_GIF_TO_TERMINAL
+    extern int isatty(int);
+    if (isatty(fileno(stdin))) {
+      error("<stdin>: is a terminal");
+      return NULL;
+    }
+#endif
     f = stdin;
+#if defined(_MSDOS) || defined(_WIN32)
+    _setmode(_fileno(stdin), _O_BINARY);
+#elif defined(__DJGPP__)
+    setmode(fileno(stdin), O_BINARY);
+#elif defined(__EMX__)
+    _fsetmode(stdin, "b");
+#endif
     name = "<stdin>";
   } else
     f = fopen(name, "rb");
@@ -520,16 +542,16 @@ get_input_stream(const char *name)
     error("%s: %s", name, strerror(errno));
     return 0;
   }
-  
+
   gfs = Gif_FullReadFile(f, GIF_READ_COMPRESSED, 0, 0);
   fclose(f);
-  
+
   if (!gfs || Gif_ImageCount(gfs) == 0) {
     error("'%s' doesn't seem to contain a GIF", name);
     Gif_DeleteStream(gfs);
     return 0;
   }
-  
+
   if (!cur_display) {
     cur_display = XOpenDisplay(cur_display_name);
     if (!cur_display) {
@@ -581,7 +603,7 @@ void
 schedule(Gt_Viewer *viewer)
 {
   Gt_Viewer *prev, *trav;
-  
+
   if (viewer->scheduled)
     unschedule(viewer);
 
@@ -596,7 +618,7 @@ schedule(Gt_Viewer *viewer)
     viewer->anim_next = animations;
     animations = viewer;
   }
-  
+
   viewer->scheduled = 1;
 }
 
@@ -611,7 +633,7 @@ schedule_next_frame(Gt_Viewer *viewer)
 
   if (viewer->timer.tv_sec == 0 && viewer->timer.tv_usec == 0)
     xwGETTIME(viewer->timer);
-  
+
   interval.tv_sec = delay / 100;
   interval.tv_usec = (delay % 100) * (MICRO_PER_SEC / 100);
   if (delay == 0)
@@ -619,7 +641,7 @@ schedule_next_frame(Gt_Viewer *viewer)
   xwADDTIME(viewer->timer, viewer->timer, interval);
 
   /* 1.Aug.2002 - leave some time to prepare the frame if necessary */
-  if (!viewer->unoptimized_pixmaps[next_pos]) {
+  if (viewer->unoptimized_frames[next_pos].pixmap) {
     xwSUBTIME(viewer->timer, viewer->timer, preparation_time);
     viewer->preparing = 1;
   }
@@ -638,7 +660,7 @@ parse_geometry(const char *const_g, XSizeHints *sh, int screen_width,
 {
   char *g = (char *)const_g;
   sh->flags = 0;
-  
+
   if (isdigit(*g)) {
     sh->flags |= USSize;
     sh->width = strtol(g, &g, 10);
@@ -648,31 +670,31 @@ parse_geometry(const char *const_g, XSizeHints *sh, int screen_width,
       goto error;
   } else if (!*g)
     goto error;
-  
+
   if (*g == '+' || *g == '-') {
     int x_minus, y_minus;
     sh->flags |= USPosition | PWinGravity;
     x_minus = *g == '-';
     sh->x = strtol(g + 1, &g, 10);
     if (x_minus) sh->x = screen_width - sh->x - sh->width;
-    
+
     y_minus = *g == '-';
     if (*g == '-' || *g == '+')
       sh->y = strtol(g + 1, &g, 10);
     else
       goto error;
     if (y_minus) sh->y = screen_height - sh->y - sh->height;
-    
+
     if (x_minus)
       sh->win_gravity = y_minus ? SouthEastGravity : NorthEastGravity;
     else
       sh->win_gravity = y_minus ? SouthWestGravity : NorthWestGravity;
-    
+
   } else if (*g)
     goto error;
-  
+
   return 1;
-  
+
  error:
   warning("bad geometry specification");
   sh->flags = 0;
@@ -700,7 +722,7 @@ create_viewer_window(Gt_Viewer *viewer, int w, int h)
     int scr_height = DisplayHeight(viewer->display, viewer->screen_number);
     parse_geometry(cur_geometry_spec, sizeh, scr_width, scr_height);
   }
-  
+
   /* Open the display and create the window */
   if (!viewer->window) {
     XSetWindowAttributes x_set_attr;
@@ -712,7 +734,7 @@ create_viewer_window(Gt_Viewer *viewer, int w, int h)
     x_set_attr.background_pixel = 0;
     x_set_attr_mask = CWColormap | CWBorderPixel | CWBackPixel
       | CWBackingStore | CWSaveUnder;
-    
+
     viewer->window = XCreateWindow
       (display, viewer->parent,
        sizeh->x, sizeh->y, sizeh->width, sizeh->height, 0,
@@ -726,7 +748,7 @@ create_viewer_window(Gt_Viewer *viewer, int w, int h)
     viewer->resizable = 0;
   viewer->width = w;
   viewer->height = h;
-  
+
   /* Set the window's title and class (for window manager resources) */
   if (viewer->top_level) {
     stringlist[0] = "gifview";
@@ -739,7 +761,7 @@ create_viewer_window(Gt_Viewer *viewer, int w, int h)
 		     NULL, 0, sizeh, NULL, &classh);
     XFree(window_name.value);
     XFree(icon_name.value);
-  
+
     if (!wm_delete_window_atom) {
       wm_delete_window_atom = XInternAtom(display, "WM_DELETE_WINDOW", False);
       wm_protocols_atom = XInternAtom(display, "WM_PROTOCOLS", False);
@@ -752,7 +774,7 @@ create_viewer_window(Gt_Viewer *viewer, int w, int h)
 		 | StructureNotifyMask);
   else
     XSelectInput(display, viewer->window, StructureNotifyMask);
-  
+
   XFree(sizeh);
 }
 
@@ -762,9 +784,9 @@ pre_delete_viewer(Gt_Viewer *viewer)
 {
   if (viewer->being_deleted) return;
   viewer->being_deleted = 1;
-  
+
   if (viewer->scheduled) unschedule(viewer);
-  
+
   if (viewer->window && !viewer->use_window)
     XDestroyWindow(viewer->display, viewer->window);
   else
@@ -792,18 +814,20 @@ set_viewer_name(Gt_Viewer *viewer, int slow_number)
   XTextProperty name_prop;
   int im_pos = (slow_number >= 0 ? slow_number : viewer->im_pos);
   int len;
-  
+
   if (!viewer->top_level || im_pos >= viewer->nim || viewer->being_deleted)
     return;
 
   gfi = viewer->im[im_pos];
-  len = strlen(viewer->name) + 21;
+  len = strlen(viewer->title) + strlen(viewer->name) + 14;
   identifier = (slow_number >= 0 ? (char *)0 : gfi->identifier);
   if (identifier)
     len += 2 + strlen(identifier);
-  
+
   strs[0] = Gif_NewArray(char, len);
-  if (slow_number >= 0)
+  if (strcmp(viewer->title, "gifview") != 0)
+    strcpy(strs[0], viewer->title);
+  else if (slow_number >= 0)
     sprintf(strs[0], "gifview: %s [#%d]", viewer->name, im_pos);
   else if (viewer->nim == 1 && identifier)
     sprintf(strs[0], "gifview: %s #%s", viewer->name, identifier);
@@ -814,11 +838,11 @@ set_viewer_name(Gt_Viewer *viewer, int slow_number)
   else
     sprintf(strs[0], "gifview: %s #%d #%s", viewer->name, im_pos, identifier);
   strs[1] = 0;
-  
+
   XStringListToTextProperty(strs, 1, &name_prop);
   XSetWMName(viewer->display, viewer->window, &name_prop);
   XSetWMIconName(viewer->display, viewer->window, &name_prop);
-  
+
   XFree(name_prop.value);
   Gif_DeleteArray(strs[0]);
 }
@@ -827,17 +851,9 @@ static Pixmap
 unoptimized_frame(Gt_Viewer *viewer, int frame, int slow)
 {
   /* create a new unoptimized frame if necessary */
-  if (!viewer->unoptimized_pixmaps[frame]) {
-    Gif_Stream *gfs = viewer->gfs;
-    Pixmap last = None, last_last = None;
-    if (frame >= 2 && gfs->images[frame-1]->disposal == GIF_DISPOSAL_PREVIOUS)
-      last_last = unoptimized_frame(viewer, frame - 2, slow);
-    if (frame >= 1)
-      last = unoptimized_frame(viewer, frame - 1, slow);
-    
-    viewer->unoptimized_pixmaps[frame] =
-      Gif_XNextImage(viewer->gfx, last_last, last, gfs, frame);
-
+  if (!viewer->unoptimized_frames[frame].pixmap) {
+    (void) Gif_XNextImage(viewer->gfx, viewer->gfs, frame,
+			  viewer->unoptimized_frames);
     if (slow) {
       set_viewer_name(viewer, frame);
       XFlush(viewer->display);
@@ -848,14 +864,14 @@ unoptimized_frame(Gt_Viewer *viewer, int frame, int slow)
   if (viewer->free_pixmaps && frame % SAVE_FRAMES == 1) {
     int kill, block_first = frame - 1, block_last = frame + SAVE_FRAMES - 1;
     for (kill = 1; kill < viewer->nim; kill++)
-      if (viewer->unoptimized_pixmaps[kill] && kill % 50 != 0
+      if (viewer->unoptimized_frames[kill].pixmap && kill % 50 != 0
 	  && (kill < block_first || kill >= block_last)) {
-	XFreePixmap(viewer->display, viewer->unoptimized_pixmaps[kill]);
-	viewer->unoptimized_pixmaps[kill] = None;
+	XFreePixmap(viewer->display, viewer->unoptimized_frames[kill].pixmap);
+	viewer->unoptimized_frames[kill].pixmap = None;
       }
   }
-  
-  return viewer->unoptimized_pixmaps[frame];
+
+  return viewer->unoptimized_frames[frame].pixmap;
 }
 
 void
@@ -864,7 +880,7 @@ prepare_frame(Gt_Viewer *viewer, int frame)
   Display *display = viewer->display;
   Window window = viewer->window;
   int changed_cursor = 0;
-  
+
   if (viewer->being_deleted || !viewer->animating)
     return;
 
@@ -873,14 +889,14 @@ prepare_frame(Gt_Viewer *viewer, int frame)
 
   /* Change cursor if we need to wait. */
   if ((viewer->animating || viewer->unoptimizing)
-      && !viewer->unoptimized_pixmaps[frame]) {
+      && !viewer->unoptimized_frames[frame].pixmap) {
     if (frame > viewer->im_pos + 10 || frame < viewer->im_pos) {
       changed_cursor = 1;
       XDefineCursor(display, window, viewer->wait_cursor);
       XFlush(display);
     }
   }
-  
+
   /* Prepare the frame */
   (void) unoptimized_frame(viewer, frame, changed_cursor);
 
@@ -901,10 +917,10 @@ view_frame(Gt_Viewer *viewer, int frame)
   Window window = viewer->window;
   Pixmap old_pixmap = viewer->pixmap;
   int need_set_name = 0;
-  
+
   if (viewer->being_deleted)
     return;
-  
+
   if (frame < 0)
     frame = 0;
   if (frame > viewer->nim - 1 && viewer->animating) {
@@ -919,28 +935,28 @@ view_frame(Gt_Viewer *viewer, int frame)
   }
   if (frame > viewer->nim - 1)
     frame = viewer->nim - 1;
-  
+
   if (frame != viewer->im_pos) {
     Gif_Image *gfi = viewer->im[frame];
     int width, height, changed_cursor = 0;
 
     /* Change cursor if we need to wait. */
     if ((viewer->animating || viewer->unoptimizing)
-	&& !viewer->unoptimized_pixmaps[frame]) {
+	&& !viewer->unoptimized_frames[frame].pixmap) {
       if (frame > viewer->im_pos + 10 || frame < viewer->im_pos) {
 	changed_cursor = 1;
 	XDefineCursor(display, window, viewer->wait_cursor);
 	XFlush(display);
       }
     }
-    
+
     /* 5/26/98 Do some noodling around to try and use memory most effectively.
        If animating, keep the uncompressed frame; otherwise, throw it away. */
     if (viewer->animating || viewer->unoptimizing)
       viewer->pixmap = unoptimized_frame(viewer, frame, changed_cursor);
     else
       viewer->pixmap = Gif_XImage(viewer->gfx, viewer->gfs, gfi);
-    
+
     /* put the image on the window */
     if (viewer->animating || viewer->unoptimizing)
       width = viewer->gfs->screen_width, height = viewer->gfs->screen_height;
@@ -972,19 +988,19 @@ view_frame(Gt_Viewer *viewer, int frame)
     /* Restore cursor */
     if (changed_cursor)
       XDefineCursor(display, window, viewer->arrow_cursor);
-    
+
     /* Do we need a new name? */
     if ((!viewer->animating && Gif_ImageCount(viewer->gfs) > 1)
 	|| old_pixmap == None)
       need_set_name = 1;
   }
-  
+
   viewer->im_pos = frame;
   viewer->preparing = 0;
-  
+
   if (need_set_name)
     set_viewer_name(viewer, -1);
-  
+
   if (!old_pixmap && !viewer->use_window)
     /* first image; map the window */
     XMapRaised(display, window);
@@ -1003,11 +1019,11 @@ frame_argument(Gt_Viewer *viewer, const char *arg)
 {
   const char *c = arg;
   int n1 = 0;
-  
+
   /* Get a number range (#x, #x-y, #x-, or #-y). First, read x. */
   if (isdigit(c[0]))
     n1 = strtol(arg, (char **)&c, 10);
-  
+
   /* It really was a number range only if c is now at the end of the
      argument. */
   if (c[0] != 0) {
@@ -1022,7 +1038,7 @@ frame_argument(Gt_Viewer *viewer, const char *arg)
       n1 = 0;
     }
   }
-  
+
   return n1;
 }
 
@@ -1045,27 +1061,27 @@ key_press(Gt_Viewer *viewer, XKeyEvent *e)
   KeySym key;
   int nbuf = XLookupString(e, buf, 32, &key, 0);
   if (nbuf > 1) buf[0] = 0;	/* ignore multikey sequences */
-  
-  if (key == XK_space || key == XK_F || key == XK_f)
-    /* space or F: one frame ahead */
+
+  if (key == XK_space || key == XK_F || key == XK_f || key == XK_N || key == XK_n)
+    /* space, N or F: one frame ahead */
     view_frame(viewer, viewer->im_pos + 1);
-  
-  else if (key == XK_B || key == XK_b)
-    /* B: one frame back */
+
+  else if (key == XK_B || key == XK_b || key == XK_P || key == XK_p)
+    /* B or P: one frame back */
     view_frame(viewer, viewer->im_pos - 1);
-  
+
   else if (key == XK_W || key == XK_w || key == XK_BackSpace)
     /* backspace: delete viewer */
     pre_delete_viewer(viewer);
-  
+
   else if (key == XK_Q || key == XK_q)
     /* Q: quit applicaton */
     exit(0);
-  
+
   else if (key == XK_S || key == XK_s || key == XK_a || key == XK_A) {
     /* S or A: toggle animation */
     switch_animating(viewer, !viewer->animating);
-    
+
     if (viewer->animating) {
       int pos = viewer->im_pos;
       if (viewer->im_pos >= viewer->nim - 1) {
@@ -1073,12 +1089,12 @@ key_press(Gt_Viewer *viewer, XKeyEvent *e)
 	viewer->anim_loop = 0;
       }
       view_frame(viewer, pos);
-      
+
     } else
       unschedule(viewer);
-    
+
     set_viewer_name(viewer, -1);
-    
+
   } else if (key == XK_U || key == XK_u) {
     /* U: toggle unoptimizing */
     int pos = viewer->im_pos;
@@ -1088,26 +1104,26 @@ key_press(Gt_Viewer *viewer, XKeyEvent *e)
       view_frame(viewer, pos);
       set_viewer_name(viewer, -1);
     }
-    
+
   } else if (key == XK_R || key == XK_r
 	     || (nbuf == 1 && buf[0] == '<')) {
     /* R or <: reset to first frame */
     unschedule(viewer);
     viewer->anim_loop = 0;
     view_frame(viewer, 0);
-    
+
   } else if (nbuf == 1 && buf[0] == '>') {
     /* >: reset to last frame */
     unschedule(viewer);
     viewer->anim_loop = 0;
     view_frame(viewer, viewer->nim - 1);
-    
+
   } else if (key == XK_Escape && viewer->animating) {
     /* Escape: stop animation */
     switch_animating(viewer, 0);
     unschedule(viewer);
     set_viewer_name(viewer, -1);
-    
+
   } else if (key == XK_Z || key == XK_z) {
     /* Z: trigger resizability */
     viewer->resizable = !viewer->resizable;
@@ -1127,12 +1143,12 @@ loop(void)
   int x_socket = ConnectionNumber(display);
   stop_delta.tv_sec = 0;
   stop_delta.tv_usec = 200000;
-  
+
   xwGETTIME(now);
   FD_ZERO(&xfds);
-  
+
   while (viewers) {
-    
+
     /* Check for any animations */
     /* 13.Feb.2001 - Use the 'pending' counter to avoid a tight loop
        if all the frames in an animation have delay 0. Reported by
@@ -1153,7 +1169,7 @@ loop(void)
       }
       xwGETTIME(now);
     }
-    
+
     pending = XPending(display);
     if (!pending) {
       /* select() until event arrives */
@@ -1165,12 +1181,12 @@ loop(void)
 	timeout_ptr = &timeout;
       } else
 	timeout_ptr = 0;
-    
+
       FD_SET(x_socket, &xfds);
       retval = select(x_socket + 1, &xfds, 0, 0, timeout_ptr);
       pending = (retval <= 0 ? 0 : FD_ISSET(x_socket, &xfds));
     }
-    
+
     if (pending)
       while (XPending(display)) {
 	XNextEvent(display, &e);
@@ -1180,33 +1196,33 @@ loop(void)
 	    if (e.type == ButtonPress && e.xbutton.button == 1)
 	      /* Left mouse button: go to next frame */
 	      view_frame(v, v->im_pos + 1);
-	    
+
 	    else if (e.type == ButtonPress && e.xbutton.button == 3)
 	      /* Right mouse button: delete window */
 	      pre_delete_viewer(v);
-	    
+
 	    else if (e.type == KeyPress)
 	      /* Key press: call function */
 	      key_press(v, &e.xkey);
 	  }
-	  
+
 	  if (e.type == ClientMessage
 	      && e.xclient.message_type == wm_protocols_atom
 	      && (Atom)(e.xclient.data.l[0]) == wm_delete_window_atom)
 	    /* WM_DELETE_WINDOW message: delete window */
 	    pre_delete_viewer(v);
-	  
+
 	  else if (e.type == MapNotify && v->animating
 		   && v->scheduled == 0)
 	    /* Window was just mapped; now, start animating it */
 	    schedule_next_frame(v);
-	  
+
 	  else if (e.type == DestroyNotify)
 	    /* Once the window has been destroyed, delete related state */
 	    delete_viewer(v);
 	}
       }
-    
+
     xwGETTIME(now);
   }
 }
@@ -1219,7 +1235,7 @@ main(int argc, char *argv[])
   int viewer_given = 0;
   int any_errors = 0;
   int first_frame = -1;
-  
+
   Clp_Parser *clp =
     Clp_NewParser(argc, (const char * const *)argv,
                   sizeof(options) / sizeof(options[0]), options);
@@ -1228,78 +1244,82 @@ main(int argc, char *argv[])
     (clp, WINDOW_TYPE, Clp_AllowNumbers,
      "root", -1,
      (const char*) 0);
-  program_name = cur_resource_name = Clp_ProgramName(clp);
-  
+  program_name = cur_resource_name = cur_window_title = Clp_ProgramName(clp);
+
   xwGETTIMEOFDAY(&genesis_time);
   preparation_time.tv_sec = 0;
   preparation_time.tv_usec = 200000;
-  
+
   while (1) {
     int opt = Clp_Next(clp);
     switch (opt) {
-      
+
      case DISPLAY_OPT:
       if (cur_display)
 	fatal_error("'--display' must come before all other options");
-      cur_display_name = clp->arg;
+      cur_display_name = clp->vstr;
       cur_display = 0;
       cur_arrow_cursor = cur_wait_cursor = None;
       break;
-      
+
+     case TITLE_OPT:
+      cur_window_title = clp->vstr;
+      break;
+
      case GEOMETRY_OPT:
-      cur_geometry_spec = clp->arg;
+      cur_geometry_spec = clp->vstr;
       break;
-      
+
      case NAME_OPT:
-      cur_resource_name = clp->arg;
+      cur_resource_name = clp->vstr;
       break;
-      
+
      case UNOPTIMIZE_OPT:
       unoptimizing = clp->negated ? 0 : 1;
       break;
-      
+
      case BACKGROUND_OPT:
-      cur_background_color = clp->arg;
+      cur_background_color = clp->vstr;
       break;
-      
+
      case ANIMATE_OPT:
       animating = clp->negated ? 0 : 1;
       break;
-      
+
      case INSTALL_COLORMAP_OPT:
       install_colormap = clp->negated ? 0 : 1;
       break;
-      
+
      case WINDOW_OPT:
       cur_use_window = clp->val.u;
       cur_use_window_new = 0;
       break;
-      
+
      case NEW_WINDOW_OPT:
       cur_use_window = clp->val.u;
       cur_use_window_new = 1;
       break;
-      
+
      case INTERACTIVE_OPT:
       interactive = clp->negated ? 0 : 1;
       break;
-      
+
      case VERSION_OPT:
       printf("gifview (LCDF Gifsicle) %s\n", VERSION);
-      printf("Copyright (C) 1997-2003 Eddie Kohler\n\
+      printf("Copyright (C) 1997-2008 Eddie Kohler\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
       exit(0);
       break;
-      
+
      case HELP_OPT:
       usage();
       exit(0);
       break;
-      
+
      case Clp_NotOption:
-      if (clp->arg[0] == '#') {
+      if (clp->vstr[0] == '#') {
 	if (!viewer_given) {
 	  viewer = get_input_stream(0);
 	  viewer_given = 1;
@@ -1310,30 +1330,30 @@ particular purpose.\n");
 	  viewer = next_viewer(viewer->gfs, viewer->name);
 	}
 	if (viewer)
-	  first_frame = frame_argument(viewer, clp->arg + 1);
+	  first_frame = frame_argument(viewer, clp->vstr + 1);
       } else {
         if (viewer) input_stream_done(viewer, first_frame);
 	first_frame = -1;
-        viewer = get_input_stream(clp->arg);
+        viewer = get_input_stream(clp->vstr);
 	viewer_given = 1;
       }
       break;
-      
+
      case Clp_Done:
       goto done;
-      
+
      case Clp_BadOption:
       any_errors = 1;
       break;
-      
+
      default:
       break;
-      
+
     }
   }
-  
+
  done:
-  
+
   if (!viewer_given) {
     if (any_errors) {
       short_usage();
@@ -1342,9 +1362,9 @@ particular purpose.\n");
     viewer = get_input_stream(0);
   }
   if (viewer) input_stream_done(viewer, first_frame);
-  
+
   if (viewers) loop();
-  
+
 #ifdef DMALLOC
   dmalloc_report();
 #endif
