@@ -28,19 +28,19 @@ verror(int seriousness, const char *fmt, va_list val)
   char pattern[BUFSIZ];
   char buffer[BUFSIZ];
   verbose_endline();
-  
+
   if (seriousness > 2)
     sprintf(pattern, "%s: fatal error: %%s\n", program_name);
   else if (seriousness == 1)
     sprintf(pattern, "%s: warning: %%s\n", program_name);
   else
     sprintf(pattern, "%s: %%s\n", program_name);
-  
+
   if (seriousness > 1)
     error_count++;
   else if (no_warnings)
     return;
-  
+
   /* try and keep error messages together (no interleaving of error messages
      from two gifsicle processes in the same command line) by calling fprintf
      only once */
@@ -48,7 +48,8 @@ verror(int seriousness, const char *fmt, va_list val)
     sprintf(buffer, pattern, fmt);
     vfprintf(stderr, buffer, val);
   } else {
-    fwrite(pattern, 1, strlen(pattern) - 3, stderr);
+    pattern[strlen(pattern) - 3] = 0;
+    fprintf(stderr, "%s", pattern);
     vfprintf(stderr, fmt, val);
     putc('\n', stderr);
   }
@@ -252,8 +253,10 @@ safe_puts(const char *s, uint32_t len, FILE *f)
   const char *last_safe = s;
   for (; len > 0; len--, s++)
     if (*s < ' ' || *s >= 0x7F || *s == '\\') {
-      if (last_safe != s)
-	fwrite(last_safe, 1, s - last_safe, f);
+      if (last_safe != s) {
+	if (fwrite(last_safe, 1, s - last_safe, f) != s - last_safe)
+	  return;
+      }
       last_safe = s + 1;
       switch (*s) {
        case '\a': fputs("\\a", f); break;
@@ -268,8 +271,10 @@ safe_puts(const char *s, uint32_t len, FILE *f)
        default:	  fprintf(f, "\\%03o", *s); break;
       }
     }
-  if (last_safe != s)
-    fwrite(last_safe, 1, s - last_safe, f);
+  if (last_safe != s) {
+    if (fwrite(last_safe, 1, s - last_safe, f) != s - last_safe)
+      return;
+  }
 }
 
 
@@ -292,7 +297,7 @@ colormap_info(FILE *where, Gif_Colormap *gfcm, char *prefix)
 {
   int i, j;
   int nrows = ((gfcm->ncol - 1) / COLORMAP_COLS) + 1;
-  
+
   for (j = 0; j < nrows; j++) {
     int which = j;
     fputs(prefix, where);
@@ -312,7 +317,7 @@ extension_info(FILE *where, Gif_Stream *gfs, Gif_Extension *gfex, int count)
   uint8_t *data = gfex->data;
   uint32_t pos = 0;
   uint32_t len = gfex->length;
-  
+
   fprintf(where, "  extension %d: ", count);
   if (gfex->kind == 255) {
     fprintf(where, "app '");
@@ -328,14 +333,14 @@ extension_info(FILE *where, Gif_Stream *gfs, Gif_Extension *gfex, int count)
     fprintf(where, " at end\n");
   else
     fprintf(where, " before #%d\n", gfex->position);
-  
+
   /* Now, hexl the data. */
   while (len > 0) {
     uint32_t row = 16;
     uint32_t i;
     if (row > len) row = len;
     fprintf(where, "    %08x: ", pos);
-    
+
     for (i = 0; i < row; i += 2) {
       if (i + 1 >= row)
 	fprintf(where, "%02x   ", data[i]);
@@ -344,12 +349,12 @@ extension_info(FILE *where, Gif_Stream *gfs, Gif_Extension *gfex, int count)
     }
     for (; i < 16; i += 2)
       fputs("     ", where);
-    
+
     putc(' ', where);
     for (i = 0; i < row; i++, data++)
       putc((*data >= ' ' && *data < 127 ? *data : '.'), where);
     putc('\n', where);
-    
+
     pos += row;
     len -= row;
   }
@@ -362,29 +367,29 @@ stream_info(FILE *where, Gif_Stream *gfs, const char *filename,
 {
   Gif_Extension *gfex;
   int n;
-  
+
   if (!gfs) return;
-  
+
   verbose_endline();
   fprintf(where, "* %s %d image%s\n", (filename ? filename : "<stdin>"),
 	  gfs->nimages, gfs->nimages == 1 ? "" : "s");
   fprintf(where, "  logical screen %dx%d\n",
 	  gfs->screen_width, gfs->screen_height);
-  
+
   if (gfs->global) {
     fprintf(where, "  global color table [%d]\n", gfs->global->ncol);
     if (colormaps) colormap_info(where, gfs->global, "  |");
     fprintf(where, "  background %d\n", gfs->background);
   }
-  
+
   if (gfs->comment)
     comment_info(where, gfs->comment, "  end comment ");
-  
+
   if (gfs->loopcount == 0)
     fprintf(where, "  loop forever\n");
   else if (gfs->loopcount > 0)
     fprintf(where, "  loop count %u\n", (unsigned)gfs->loopcount);
-  
+
   for (n = 0, gfex = gfs->extensions; gfex; gfex = gfex->next, n++)
     if (extensions)
       extension_info(where, gfs, gfex, n);
@@ -403,37 +408,37 @@ image_info(FILE *where, Gif_Stream *gfs, Gif_Image *gfi, int colormaps)
   int num;
   if (!gfs || !gfi) return;
   num = Gif_ImageNumber(gfs, gfi);
-  
+
   verbose_endline();
   fprintf(where, "  + image #%d ", num);
   if (gfi->identifier)
     fprintf(where, "#%s ", gfi->identifier);
-  
+
   fprintf(where, "%dx%d", gfi->width, gfi->height);
   if (gfi->left || gfi->top)
     fprintf(where, " at %d,%d", gfi->left, gfi->top);
-  
+
   if (gfi->interlace)
     fprintf(where, " interlaced");
-  
+
   if (gfi->transparent >= 0)
     fprintf(where, " transparent %d", gfi->transparent);
-  
+
 #if defined(PRINT_SIZE)
   if (gfi->compressed)
     fprintf(where, " compressed size %u min_code_size %d", gfi->compressed_len, *gfi->compressed);
 #endif
-  
+
   fprintf(where, "\n");
-  
+
   if (gfi->comment)
     comment_info(where, gfi->comment, "    comment ");
-  
+
   if (gfi->local) {
     fprintf(where, "    local color table [%d]\n", gfi->local->ncol);
     if (colormaps) colormap_info(where, gfi->local, "    |");
   }
-  
+
   if (gfi->disposal || gfi->delay) {
     fprintf(where, "   ");
     if (gfi->disposal)
@@ -452,7 +457,7 @@ explode_filename(const char *filename, int number, const char *name, int max_nim
   static char *s;
   int l = strlen(filename);
   l += name ? strlen(name) : 10;
-  
+
   Gif_Delete(s);
   s = Gif_NewArray(char, l + 3);
   if (name)
@@ -467,7 +472,7 @@ explode_filename(const char *filename, int number, const char *name, int max_nim
       j *= 10;
     sprintf(s, "%s.%0*d", filename, digits, number);
   }
-  
+
   return s;
 }
 
@@ -493,16 +498,16 @@ parse_frame_spec(Clp_Parser *clp, const char *arg, int complain, void *thunk)
 {
   char *c;
   (void)thunk;
-  
+
   frame_spec_1 = 0;
   frame_spec_2 = -1;
   frame_spec_name = 0;
-  
+
   if (!input && !input_name)
     input_stream(0);
   if (!input)
     return 0;
-  
+
   if (arg[0] != '#') {
     if (complain)
       return Clp_OptionError(clp, "frame specifications must start with #");
@@ -511,7 +516,7 @@ parse_frame_spec(Clp_Parser *clp, const char *arg, int complain, void *thunk)
   }
   arg++;
   c = (char *)arg;
-  
+
   /* Get a number range (#x, #x-y, or #x-). First, read x. */
   if (isdigit(c[0]))
     frame_spec_1 = frame_spec_2 = strtol(c, &c, 10);
@@ -521,7 +526,7 @@ parse_frame_spec(Clp_Parser *clp, const char *arg, int complain, void *thunk)
       return complain ? Clp_OptionError(clp, "there are only %d frames",
 					Gif_ImageCount(input)) : 0;
   }
-  
+
   /* Then, if the next character is a dash, read y. Be careful to prevent
      #- from being interpreted as a frame range. */
   if (c[0] == '-' && (frame_spec_2 > 0 || c[1] != 0)) {
@@ -533,7 +538,7 @@ parse_frame_spec(Clp_Parser *clp, const char *arg, int complain, void *thunk)
     else
       frame_spec_2 = Gif_ImageCount(input) - 1;
   }
-  
+
   /* It really was a number range (and not a frame name)
      only if c is now at the end of the argument. */
   if (c[0] != 0) {
@@ -550,14 +555,14 @@ parse_frame_spec(Clp_Parser *clp, const char *arg, int complain, void *thunk)
       return Clp_OptionError(clp, "no frame named '#%s'", arg);
     else
       return 0;
-    
+
   } else {
     if (frame_spec_1 >= 0 && frame_spec_1 <= frame_spec_2
 	&& frame_spec_2 < Gif_ImageCount(input))
       return 1;
     else if (!complain)
       return 0;
-    
+
     if (frame_spec_1 == frame_spec_2)
       return Clp_OptionError(clp, "no frame number #%d", frame_spec_1);
     else if (frame_spec_1 < 0)
@@ -590,7 +595,7 @@ parse_dimensions(Clp_Parser *clp, const char *arg, int complain, void *thunk)
     if (*val == 0)
       return 1;
   }
-  
+
   if (complain)
     return Clp_OptionError(clp, "invalid dimensions '%s' (want WxH)", arg);
   else
@@ -602,14 +607,14 @@ parse_position(Clp_Parser *clp, const char *arg, int complain, void *thunk)
 {
   char *val;
   (void)thunk;
-  
+
   position_x = strtol(arg, &val, 10);
   if (*val == ',') {
     position_y = strtol(val + 1, &val, 10);
     if (*val == 0)
       return 1;
   }
-  
+
   if (complain)
     return Clp_OptionError(clp, "invalid position '%s' (want 'X,Y')", arg);
   else
@@ -621,7 +626,7 @@ parse_scale_factor(Clp_Parser *clp, const char *arg, int complain, void *thunk)
 {
   char *val;
   (void)thunk;
-  
+
   parsed_scale_factor_x = strtod(arg, &val);
   if (*val == 'x') {
     parsed_scale_factor_y = strtod(val + 1, &val);
@@ -631,7 +636,7 @@ parse_scale_factor(Clp_Parser *clp, const char *arg, int complain, void *thunk)
     parsed_scale_factor_y = parsed_scale_factor_x;
     return 1;
   }
-  
+
   if (complain)
     return Clp_OptionError(clp, "invalid scale factor '%s' (want XxY)", arg);
   else
@@ -645,7 +650,7 @@ parse_rectangle(Clp_Parser *clp, const char *arg, int complain, void *thunk)
   char *val;
   int x = position_x = strtol(arg, &val, 10);
   (void)thunk;
-  
+
   if (*val == ',') {
     int y = position_y = strtol(val + 1, &val, 10);
     if (*val == '-' && parse_position(clp, val + 1, 0, 0)) {
@@ -672,7 +677,7 @@ parse_rectangle(Clp_Parser *clp, const char *arg, int complain, void *thunk)
       return 1;
     }
   }
-  
+
   if (complain)
     return Clp_OptionError(clp, "invalid rectangle '%s' (want 'X1,Y1-X2,Y2' or 'X1,Y1+WxH'", input_arg);
   else
@@ -716,7 +721,7 @@ parse_color(Clp_Parser *clp, const char *arg, int complain, void *thunk)
   char *str;
   int red, green, blue;
   (void)thunk;
-  
+
   if (*arg == '#') {
     int len = strlen(++arg);
     if (len == 0 || len % 3 != 0
@@ -726,16 +731,16 @@ parse_color(Clp_Parser *clp, const char *arg, int complain, void *thunk)
 			input_arg);
       return 0;
     }
-    
+
     len /= 3;
     red	  = parse_hex_color_channel(&arg[ 0 * len ], len);
     green = parse_hex_color_channel(&arg[ 1 * len ], len);
     blue  = parse_hex_color_channel(&arg[ 2 * len ], len);
     goto gotrgb;
-    
+
   } else if (!isdigit(*arg))
     goto error;
-  
+
   red = strtol(arg, &str, 10);
   if (*str == 0) {
     if (red < 0 || red > 255)
@@ -743,18 +748,18 @@ parse_color(Clp_Parser *clp, const char *arg, int complain, void *thunk)
     parsed_color.haspixel = 1;
     parsed_color.pixel = red;
     return 1;
-    
+
   } else if (*str != ',' && *str != '/')
     goto error;
-  
+
   if (*++str == 0) goto error;
   green = strtol(str, &str, 10);
   if (*str != ',' && *str != '/') goto error;
-  
+
   if (*++str == 0) goto error;
   blue = strtol(str, &str, 10);
   if (*str != 0) goto error;
-  
+
  gotrgb:
   if (red < 0 || green < 0 || blue < 0
       || red > 255 || green > 255 || blue > 255)
@@ -764,7 +769,7 @@ parse_color(Clp_Parser *clp, const char *arg, int complain, void *thunk)
   parsed_color.blue = blue;
   parsed_color.haspixel = 0;
   return 1;
-  
+
  error:
   if (complain)
     return Clp_OptionError(clp, "invalid color '%s'", input_arg);
@@ -779,16 +784,16 @@ parse_two_colors(Clp_Parser *clp, const char *arg, int complain, void *thunk)
   if (parse_color(clp, arg, complain, thunk) <= 0)
     return 0;
   old_color = parsed_color;
-  
+
   arg = Clp_Shift(clp, 0);
   if (!arg && complain)
     return Clp_OptionError(clp, "'%O' takes two color arguments");
   else if (!arg)
     return 0;
-  
+
   if (parse_color(clp, arg, complain, thunk) <= 0)
     return 0;
-  
+
   parsed_color2 = parsed_color;
   parsed_color = old_color;
   return 1;
@@ -808,9 +813,9 @@ read_text_colormap(FILE *f, const char *name)
   int ncol = 0;
   unsigned red, green, blue;
   float fred, fgreen, fblue;
-  
+
   while (fgets(buf, BUFSIZ, f)) {
-    
+
     if (sscanf(buf, "%g %g %g", &fred, &fgreen, &fblue) == 3) {
       if (fred < 0) fred = 0;
       if (fgreen < 0) fgreen = 0;
@@ -819,7 +824,7 @@ read_text_colormap(FILE *f, const char *name)
       green = (unsigned)(fgreen + .5);
       blue = (unsigned)(fblue + .5);
       goto found;
-      
+
     } else if (sscanf(buf, "#%2x%2x%2x", &red, &green, &blue) == 3) {
      found:
       if (red > 255) red = 255;
@@ -835,7 +840,7 @@ read_text_colormap(FILE *f, const char *name)
 	ncol++;
       }
     }
-    
+
     /* handle too-long lines gracefully */
     if (strchr(buf, '\n') == 0) {
       int c;
@@ -843,7 +848,7 @@ read_text_colormap(FILE *f, const char *name)
 	;
     }
   }
-  
+
   if (ncol == 0) {
     error("'%s' doesn't seem to contain a colormap", name);
     Gif_DeleteColormap(cm);
@@ -860,7 +865,7 @@ read_colormap_file(const char *name, FILE *f)
   Gif_Colormap *cm = 0;
   int c;
   int my_file = 0;
-  
+
   if (name && strcmp(name, "-") == 0)
     name = 0;
   if (!f) {
@@ -874,10 +879,10 @@ read_colormap_file(const char *name, FILE *f)
       return 0;
     }
   }
-  
+
   name = name ? name : "<stdin>";
   if (verbosing) verbose_open('<', name);
-  
+
   c = getc(f);
   ungetc(c, f);
   if (c == 'G') {
@@ -891,11 +896,11 @@ read_colormap_file(const char *name, FILE *f)
 	warning("there were errors reading '%s'", name);
       cm = Gif_CopyColormap(gfs->global);
     }
-    
+
     Gif_DeleteStream(gfs);
   } else
     cm = read_text_colormap(f, name);
-  
+
   if (my_file) fclose(f);
   if (verbosing) verbose_close('>');
   return cm;
@@ -923,19 +928,19 @@ void
 clear_def_frame_once_options(void)
 {
   /* Get rid of next-frame-only options.
-     
+
      This causes problems with frame selection. In the command 'gifsicle
      -nblah f.gif', the name should be applied to frame 0 of f.gif. This will
      happen automatically when f.gif is read, since all of its frames will be
      added when it is input. After frame 0, the name in def_frame will be
      cleared.
-     
+
      Now, 'gifsicle -nblah f.gif #1' should apply the name to frame 1 of
      f.gif. But once f.gif is input, its frames are added, and the name
      component of def_frame is cleared!! So when #1 comes around it's gone!
-     
+
      We handle this in gifsicle.c using the _change fields. */
-  
+
   def_frame.name = 0;
   def_frame.comment = 0;
   def_frame.extensions = 0;
@@ -962,9 +967,9 @@ add_frame(Gt_Frameset *fset, int number, Gif_Stream *gfs, Gif_Image *gfi)
   fset->f[number] = def_frame;
   fset->f[number].stream = gfs;
   fset->f[number].image = gfi;
-  
+
   clear_def_frame_once_options();
-  
+
   return &fset->f[number];
 }
 
@@ -1012,7 +1017,7 @@ merger_flatten(Gt_Frameset *fset, int f1, int f2)
   assert(f1 >= 0 && f2 < fset->count);
   for (i = f1; i <= f2; i++) {
     Gt_Frameset *nest = FRAME(fset, i).nest;
-    
+
     if (nest && nest->count > 0) {
       if (FRAME(fset, i).use < 0 && nest->count == 1) {
 	/* use < 0 means use the frame's delay, disposal and name (if not
@@ -1027,7 +1032,7 @@ merger_flatten(Gt_Frameset *fset, int f1, int f2)
       }
       merger_flatten(nest, 0, nest->count - 1);
     }
-    
+
     if (FRAME(fset, i).use > 0)
       merger_add(&FRAME(fset, i));
   }
@@ -1041,7 +1046,7 @@ find_color_or_error(Gif_Color *color, Gif_Stream *gfs, Gif_Image *gfi,
   Gif_Colormap *gfcm = gfs->global;
   int index;
   if (gfi && gfi->local) gfcm = gfi->local;
-  
+
   if (color->haspixel == 2) {	/* have pixel value, not color */
     if (color->pixel < (uint32_t)gfcm->ncol)
       return color->pixel;
@@ -1051,7 +1056,7 @@ find_color_or_error(Gif_Color *color, Gif_Stream *gfs, Gif_Image *gfi,
       return -1;
     }
   }
-  
+
   index = Gif_FindColor(gfcm, color);
   if (index < 0 && color_context)
     error("%s color not in colormap", color_context);
@@ -1132,7 +1137,7 @@ set_background(Gif_Stream *gfs, Gt_OutputData *output_data)
 	gfs->background = 0;
 	return;
     }
-    
+
   search:
     i = find_color_or_error(&background, gfs, 0, "background");
     gfs->background = (i >= 0 ? i : 0);
@@ -1152,7 +1157,7 @@ fix_total_crop(Gif_Stream *dest, Gif_Image *srci, int merger_index)
   prev_image = dest->images[dest->nimages - 1];
   if (merger_index < nmerger - 1)
       next_fr = merger[merger_index + 1];
-  
+
   /* Don't save identifiers since the frame that was to be identified, is
      gone. Save comments though. */
   if (!fr->no_comments && srci->comment && next_fr) {
@@ -1165,7 +1170,7 @@ fix_total_crop(Gif_Stream *dest, Gif_Image *srci, int merger_index)
     Gif_DeleteComment(fr->comment);
     fr->comment = 0;
   }
-  
+
   /* Save delay by adding it to the previous frame's delay. */
   if (fr->delay < 0)
     fr->delay = srci->delay;
@@ -1191,15 +1196,15 @@ static void
 handle_flip_and_screen(Gif_Stream *dest, Gif_Image *desti, Gt_Frame *fr)
 {
   Gif_Stream *gfs = fr->stream;
-  
+
   uint16_t screen_width = gfs->screen_width;
   uint16_t screen_height = gfs->screen_height;
-  
+
   if (fr->flip_horizontal)
     flip_image(desti, screen_width, screen_height, 0);
   if (fr->flip_vertical)
     flip_image(desti, screen_width, screen_height, 1);
-  
+
   if (fr->rotation == 1)
     rotate_image(desti, screen_width, screen_height, 1);
   else if (fr->rotation == 2) {
@@ -1207,7 +1212,7 @@ handle_flip_and_screen(Gif_Stream *dest, Gif_Image *desti, Gt_Frame *fr)
     flip_image(desti, screen_width, screen_height, 1);
   } else if (fr->rotation == 3)
     rotate_image(desti, screen_width, screen_height, 3);
-  
+
   /* handle screen size, which might have height & width exchanged */
   if (fr->rotation == 1 || fr->rotation == 3)
     handle_screen(dest, screen_height, screen_width);
@@ -1244,7 +1249,7 @@ analyze_crop(int nmerger, Gt_Crop *crop)
       if (tt + hh > b)
 	b = tt + hh;
     }
-  
+
   crop->x = crop->spec_x + l;
   crop->y = crop->spec_y + t;
   crop->w = crop->spec_w <= 0 ? (r - crop->x) + crop->spec_w : crop->spec_w;
@@ -1268,12 +1273,12 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
   Gif_Stream *dest = Gif_NewStream();
   Gif_Colormap *global = Gif_NewFullColormap(256, 256);
   int i, same_compressed_ok, all_same_compressed_ok;
-  
+
   global->ncol = 0;
   dest->global = global;
   /* 11/23/98 A new stream's screen size is 0x0; we'll use the max of the
      merged-together streams' screen sizes by default (in merge_stream()) */
-  
+
   if (f2 < 0) f2 = fset->count - 1;
   nmerger = 0;
   merger_flatten(fset, f1, f2);
@@ -1293,7 +1298,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
       compress_immediately = 1;
     }
   }
-  
+
   /* merge stream-specific info and clear colormaps */
   for (i = 0; i < nmerger; i++)
     merger[i]->stream->userflags = 1;
@@ -1308,7 +1313,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
     if (merger[i]->image->local)
       unmark_colors_2(merger[i]->image->local);
   }
-  
+
   /* is it ok to save the same compressed image? This is true only if we
      will recompress later from scratch. */
   /* 13.Aug.2002 - Can't save the same compressed image if we crop, so turn
@@ -1321,7 +1326,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
     all_same_compressed_ok = 1;
   else
     all_same_compressed_ok = 0;
-  
+
   /* analyze crops */
   for (i = 0; i < nmerger; i++)
     if (merger[i]->crop)
@@ -1329,7 +1334,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
   for (i = 0; i < nmerger; i++)
     if (merger[i]->crop && !merger[i]->crop->ready)
       analyze_crop(nmerger, merger[i]->crop);
-  
+
   /* copy stream-wide information from output_data */
   if (output_data->loopcount > -2)
     dest->loopcount = output_data->loopcount;
@@ -1341,7 +1346,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
     Gif_Image *srci;
     Gif_Image *desti;
     int old_transparent;
-    
+
     /* First, check for extensions */
     {
       int j;
@@ -1360,7 +1365,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
 	gfex = next;
       }
     }
-    
+
     /* Make a copy of the image and crop it if we're cropping */
     if (fr->crop) {
       srci = Gif_CopyImage(fr->image);
@@ -1375,7 +1380,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
       srci = fr->image;
       Gif_UncompressImage(srci);
     }
-    
+
     /* It was pretty stupid to remove this code, which I did between 1.2b6 and
        1.2 */
     old_transparent = srci->transparent;
@@ -1393,17 +1398,17 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
     if ((fr->interlacing >= 0 && fr->interlacing != srci->interlace)
 	|| fr->flip_horizontal || fr->flip_vertical || fr->rotation)
       same_compressed_ok = 0;
-    
+
     desti = merge_image(dest, fr->stream, srci, same_compressed_ok);
-    
+
     srci->transparent = old_transparent; /* restore real transparent value */
-    
+
     /* Flipping and rotating, and also setting the screen size */
     if (fr->flip_horizontal || fr->flip_vertical || fr->rotation)
       handle_flip_and_screen(dest, desti, fr);
     else
       handle_screen(dest, fr->stream->screen_width, fr->stream->screen_height);
-    
+
     /* Names and comments */
     if (fr->name || fr->no_name) {
       Gif_DeleteArray(desti->identifier);
@@ -1421,14 +1426,14 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
       Gif_DeleteComment(fr->comment);
       fr->comment = 0;
     }
-    
+
     if (fr->interlacing >= 0)
       desti->interlace = fr->interlacing;
     if (fr->left >= 0)
       desti->left = fr->left + (fr->position_is_offset ? desti->left : 0);
     if (fr->top >= 0)
       desti->top = fr->top + (fr->position_is_offset ? desti->top : 0);
-    
+
     if (fr->delay >= 0)
       desti->delay = fr->delay;
     if (fr->disposal >= 0)
@@ -1445,7 +1450,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
       Gif_UncompressImage(desti);
       Gif_ReleaseCompressedImage(desti);
     }
-    
+
    merge_frame_done:
     /* 6/17/02 store information about image's background */
     if (fr->stream->images[0]->transparent >= 0)
@@ -1459,7 +1464,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
     /* Destroy the copied, cropped image if necessary */
     if (fr->crop)
       Gif_DeleteImage(srci);
-    
+
     /* if we can, delete the image's data right now to save memory */
     srci = fr->image;
     assert(srci->refcount > 1);
@@ -1469,7 +1474,7 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
       Gif_ReleaseCompressedImage(srci);
       fr->image = 0;
     }
-    
+
     /* 5/26/98 Destroy the stream now to help with memory. Assumes that
        all frames are added with add_frame() which properly increments the
        stream's refcount. Set field to 0 so we don't redelete */
@@ -1501,14 +1506,14 @@ merge_frame_interval(Gt_Frameset *fset, int f1, int f2,
       dest->screen_height = (merger[0]->crop->h > 0 ? merger[0]->crop->h : 0);
     }
   }
-  
+
   /* Set the logical screen from the user's preferences */
   if (output_data->screen_width >= 0)
     dest->screen_width = output_data->screen_width;
   if (output_data->screen_height >= 0)
     dest->screen_height = output_data->screen_height;
   Gif_CalculateScreenSize(dest, 0);
-  
+
   /* Find the background color in the colormap, or add it if we can */
   set_background(dest, output_data);
 
